use anyhow::Result;
use jsonwebtoken::{DecodingKey, Validation};
use serde::{Deserialize, Serialize};
use std::collections::{HashMap, HashSet};
use std::fs;
use std::path::Path;
use uuid::Uuid;

pub mod device;
pub mod handlers;

#[derive(Debug, Deserialize, Clone)]
pub struct Config {
    pub devices: HashMap<Uuid, device::Config>,
}

pub fn read_config(path: &Path) -> Result<Config> {
    let buf = fs::read(path)?;
    let config = serde_json::from_slice(&buf)?;

    Ok(config)
}

pub struct AppState {
    pub devices: HashMap<Uuid, device::Config>,
    pub devices_api: HashMap<Uuid, kdash_protocol::Config>,
    pub devices_api_json: HashMap<Uuid, Vec<u8>>,
    pub device_ids: HashSet<Uuid>,
    pub jwt_decoding_key: DecodingKey,
    pub jwt_validation: Validation,
}

#[derive(Debug, Serialize, Deserialize, Clone)]
pub struct Claims {
    pub exp: i64,
    pub sub: Uuid,
}
